@@ -14,13 +14,13 @@
 /* ecbuild info */
 
 #ifndef ECBUILD_VERSION_STR
-#define ECBUILD_VERSION_STR "3.11.0"
+#define ECBUILD_VERSION_STR "3.12.0"
 #endif
 #ifndef ECBUILD_VERSION
-#define ECBUILD_VERSION "3.11.0"
+#define ECBUILD_VERSION "3.12.0"
 #endif
 #ifndef ECBUILD_MACROS_DIR
-#define ECBUILD_MACROS_DIR  "/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_science_ecCodes/ecCodes/work/eccodes-2.42.0-Source/cmake"
+#define ECBUILD_MACROS_DIR  "/opt/local/var/macports/build/ecCodes-5968d902/work/eccodes-2.44.0-Source/cmake"
 #endif
 
 /* config info */
@@ -32,7 +32,7 @@
 #define ECCODES_OS_VERSION       "16.7.0"
 #define ECCODES_SYS_PROCESSOR    "x86_64"
 
-#define ECCODES_BUILD_TIMESTAMP  "20250630163310"
+#define ECCODES_BUILD_TIMESTAMP  "20251007172633"
 #define ECCODES_BUILD_TYPE       "Release"
 
 #define ECCODES_C_COMPILER_ID      "Clang"
@@ -54,17 +54,17 @@
 #define ECCODES_INSTALL_LIB_DIR   "/opt/local/lib"
 #define ECCODES_INSTALL_DATA_DIR  "/opt/local/share/eccodes"
 
-#define ECCODES_DEVELOPER_SRC_DIR "/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_science_ecCodes/ecCodes/work/eccodes-2.42.0-Source"
-#define ECCODES_DEVELOPER_BIN_DIR "/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_science_ecCodes/ecCodes/work/build"
+#define ECCODES_DEVELOPER_SRC_DIR "/opt/local/var/macports/build/ecCodes-5968d902/work/eccodes-2.44.0-Source"
+#define ECCODES_DEVELOPER_BIN_DIR "/opt/local/var/macports/build/ecCodes-5968d902/work/build"
 
 /* Fortran support */
 
 #if 1
 
 #define ECCODES_Fortran_COMPILER_ID      "GNU"
-#define ECCODES_Fortran_COMPILER_VERSION "14.2.0"
+#define ECCODES_Fortran_COMPILER_VERSION "15.1.0"
 
-#define ECCODES_Fortran_COMPILER "/opt/local/bin/gfortran-mp-14"
+#define ECCODES_Fortran_COMPILER "/opt/local/bin/gfortran-mp-15"
 #define ECCODES_Fortran_FLAGS    "-pipe -Os -fallow-argument-mismatch -m64 -O3 -DNDEBUG -funroll-all-loops -finline-functions"
 
 #endif
